@@ -1,7 +1,7 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2010-2011 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2010 -- leonerd@leonerd.org.uk
 
 package IO::Async::Timer::Absolute;
 
@@ -9,7 +9,7 @@ use strict;
 use warnings;
 use base qw( IO::Async::Timer );
 
-our $VERSION = '0.60_004';
+our $VERSION = '0.32';
 
 use Carp;
 
@@ -24,7 +24,7 @@ C<IO::Async::Timer::Absolute> - event callback at a fixed future time
  use POSIX qw( mktime );
 
  use IO::Async::Loop;
- my $loop = IO::Async::Loop->new;
+ my $loop = IO::Async::Loop->new();
 
  my @time = gmtime;
 
@@ -33,13 +33,15 @@ C<IO::Async::Timer::Absolute> - event callback at a fixed future time
 
     on_expire => sub {
        print "It's midnight\n";
-       $loop->stop;
+       $loop->loop_stop;
     },
  );
 
+ $timer->start;
+
  $loop->add( $timer );
 
- $loop->run;
+ $loop->loop_forever;
 
 =head1 DESCRIPTION
 
@@ -110,7 +112,7 @@ sub configure
       $self->start if !$self->is_running;
    }
 
-   unless( $self->can_event( 'on_expire' ) ) {
+   if( !$self->{on_expire} and !$self->can( 'on_expire' ) ) {
       croak 'Expected either a on_expire callback or an ->on_expire method';
    }
 
@@ -122,7 +124,7 @@ sub _make_cb
    my $self = shift;
 
    return $self->_capture_weakself( sub {
-      my $self = shift or return;
+      my ( $self ) = @_;
 
       undef $self->{id};
 
@@ -134,13 +136,14 @@ sub _make_enqueueargs
 {
    my $self = shift;
 
-   return at => $self->{time};
+   return time => $self->{time};
 }
 
+# Keep perl happy; keep Britain tidy
+1;
+
+__END__
+
 =head1 AUTHOR
 
 Paul Evans <leonerd@leonerd.org.uk>
-
-=cut
-
-0x55AA;
